import 'package:flutter/material.dart';
import 'package:softcorp_flutter_core/default_card/default_card.dart';
import 'package:softcorp_flutter_core/text_theme/text_theme.dart';

import '../constants.dart';

class DefaultFormField extends StatefulWidget {
  final TextEditingController textEditingController;
  final TextInputType textInputType;
  final String hint;
  final String label;
  final String? Function(String?)? validator;
  final BoxConstraints? constraints;
  final int? numberOfLines;
  final bool? disabled;
  final bool? addDefaultBorder;
  final Color? labelColor;
  final IconData? prefixIcon;
  final bool? obscureText;

  const DefaultFormField({
    Key? key,
    required this.textEditingController,
    required this.textInputType,
    required this.hint,
    required this.label,
    this.validator,
    this.addDefaultBorder,
    this.constraints,
    this.numberOfLines,
    this.disabled,
    this.labelColor,
    this.prefixIcon,
    this.obscureText,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DefaultFormFieldState();
  }
}

class _DefaultFormFieldState extends State<DefaultFormField> {
  late Color _shadowColor = defaultLightShadow;
  double _cardElevation = defaultElevation;

  @override
  Widget build(BuildContext context) {
    return StatefulBuilder(builder: (context, setStateForCard) {
      return Focus(
        onFocusChange: (hasFocus) {
          if(hasFocus == true){
            setStateForCard((){
              _shadowColor = softcorpPrimaryColor;
              _cardElevation = 10;
            });
          } else {
            setStateForCard((){
              _shadowColor = defaultLightShadow;
              _cardElevation = defaultElevation;
            });
          }
        },
        child: DefaultCard(
          shadowColor: _shadowColor,
          elevation: _cardElevation,
          child: TextFormField(
            enabled: widget.disabled == null ? true : (widget.disabled),
            controller: widget.textEditingController,
            obscureText: widget.obscureText ?? false,
            keyboardType: widget.textInputType,
            style: const TextStyle(color: Colors.black),
            decoration: InputDecoration(
              hintText: widget.hint,
              hoverColor:
                  widget.disabled == true ? Colors.grey[200] : Colors.white,
              disabledBorder:
                  const OutlineInputBorder(borderSide: BorderSide.none),
              enabledBorder:
                  const OutlineInputBorder(borderSide: BorderSide.none),
              focusedBorder:
                  const OutlineInputBorder(borderSide: BorderSide.none),
              errorBorder:
                  const OutlineInputBorder(borderSide: BorderSide.none),
              focusedErrorBorder:
                  const OutlineInputBorder(borderSide: BorderSide.none),
              hintStyle: const TextStyle(fontSize: 16, color: Colors.grey),
              filled: true,
              prefixIcon: widget.prefixIcon != null
                  ? Icon(
                      widget.prefixIcon,
                      size: 15,
                      color: defaultSubTitleColor,
                    )
                  : null,
              contentPadding: const EdgeInsets.all(16),
              fillColor:
                  widget.disabled == true ? Colors.grey[200] : Colors.white,
            ),
            validator: (String? val) {
              if (widget.validator == null) {
                return null;
              }
              String? validator = widget.validator!(val);
              if (validator != null) {
                setStateForCard(() {
                  _shadowColor = defaultDangerColor;
                  _cardElevation = 10;
                });
              }
              return validator;
            },
            maxLines: widget.obscureText == true ? 1 : widget.numberOfLines,
          ),
        ),
      );
    });
  }
}
